@@ -95,8 +95,8 @@ class CoreObject(dbus.service.Object):
                         OpenSSL.SSL.FILETYPE_PEM, cert)
                     subject = cert_obj.get_subject().get_components()
                     for subj in subject:
-                        if subj[0] == 'CN':
-                            return subj[1]
+                        if subj[0] == b'CN':
+                            return str(subj[1], 'utf-8')
         except Exception:
             pass
         return "localhost"
