@@ -16,7 +16,7 @@
 
 import sys
 from calculate.lib.configparser import ConfigParser
-from calculate.lib.utils.files import pathJoin, readFile, writeFile
+from calculate.lib.utils.files import pathJoin, writeFile, readFileEx
 from calculate.lib.utils.text import _u8
 import re
 from os import path
