@@ -314,8 +314,11 @@ class Tasks(object):
         """
         Выполнена хотя бы одна задача и все те, которые выполнены с ошибкой
         """
+        def not_empty_all(l):
+            l = list(l)
+            return bool(l and all(l))
         return cls(
-            lambda *args: any(not cls._result(*args)[x] for x in tasks if x in cls._result(*args)))
+            lambda *args: not_empty_all(not cls._result(*args)[x] for x in tasks if x in cls._result(*args)))
 
     @classmethod
     def failed_one_of(cls, *tasks):
